Security Advisories (4)
CVE-2006-4484 (2008-10-01)

Buffer overflow in the LWZReadByte_ function in the GD extension in allows remote attackers to have an unknown impact via a GIF file with input_code_size greater than MAX_LWZ_BITS, which triggers an overflow when initializing the table array.

CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2007-4772 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows context-dependent attackers to cause a denial of service (infinite loop) via a crafted regular expression.

CVE-2007-6067 (2008-01-09)

Algorithmic complexity vulnerability in the regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (memory consumption) via a crafted "complex" regular expression with doubly-nested states.

NAME

Tk::IO - high level interface to Tk's 'fileevent' mechanism

SYNOPSIS

my $fh = Tk::IO->new(-linecommand => callback, -childcommand => callback);
$fh->exec("command")
$fh->wait
$fh->kill

WARNING

INTERFACES TO THIS MODULE MAY CHANGE AS PERL'S IO EVOLVES AND WITH PORT OF TK4.1

DESCRIPTION

Tk::IO is now layered on perl's IO::Handle class. Interfaces have changed, and are still evolving.

In theory C methods which enable non-blocking IO as in earlier Tk-b* release(s) are still there. I have not changed them to use perl's additional Configure information, or tested them much.

Assumption is that exec is used to fork a child process and a callback is called each time a complete line arrives up the implied pipe.

"line" should probably be defined in terms of perl's input record separator but is not yet.

The -childcommand callback is called when end-of-file occurs.

$fh->wait can be used to wait for child process while processing other Tk events.

$fh->kill can be used to send signal to child process.

BUGS

Still not finished. Idea is to use "exec" to emulate "system" in a non-blocking manner.